@@ -1,5 +1,5 @@
 
-def theme():
+def theme(context):
     # CMake theme:
     #  actions performing in cyan
     performing="cyan"
@@ -8,7 +8,13 @@ def theme():
     #  actions taking an unknown time
     untimed="blue"
 
-    return [
+    # If the user do not ask for his own colormap
+    if not context["user_defined_colormaps"]:
+        # A palette that goes: purple, orange, white
+        percs = [45, 39, 33, 27, 21, 57, 63, 62, 98, 97, 133, 132, 138, 173, 172, 208, 214, 220, 226, 228, 229, 230, 231, 255]
+        context["colormaps"]["Scale"] = percs
+
+    return context,[
         # Configure...
         [ "^--.*works", performed ],
         [ "^--.*done", performed ],
@@ -19,26 +25,30 @@ def theme():
         [ "^-- Configuring incomplete, errors occurred!", "red" ],
         [ "^--.*", performing ],
         # Errors
-        [ "CMake Error:", "red" ],
+        [ "CMake Error", "red" ],
         [ "CMake Warning", "yellow" ],
         # Scan
         [ "^(Scanning dependencies of target)(.*)$",
           performing, "normal,bold" ],
-        # Link
-        [ "^(Linking .* )(library|executable) (.*/)*(.+(\.[aso]+)*)$",
+        # Link (make)
+        # [ "^(Linking .* )(library|executable) (.*/)*(.+(\.[aso]+)*)$",
+        [ "^(Linking .* )(library|executable) (.*)$",
           untimed, "normal,normal,bold" ],
+        # [percent] Creating something
+        [ "^\[\s*[0-9/]+%?\]\s(.*Creating.*)$",
+          performing, "normal" ],
         # [percent] Built
-        [ "^\[\s*[0-9]+%\]\s(Built target)(\s.*)$",
+        [ "^\[\s*[0-9/]+%?\]\s(Built target)(\s.*)$",
           performed, "normal,bold" ],
         # [percent] Building
-        [ "^\[\s*[0-9]+%\]\s(Building \w* object)(\s+.*/)([-\w]+.c.*)(.o)$",
-            performing, "normal,normal,bold,normal"],
+        [ "^\[\s*[0-9/]+%?\]\s(Building \w* object)\s+(.*)(\.dir)(.*/)([-\w]+).c.*.o$",
+            performing+","+performing+","+performing+",Hash,"+performing, "normal,normal,normal,normal,bold"],
         # [percent] Generating
-        [ "^\[\s*[0-9]+%\]\s(Generating)(\s+.*)$",
+        [ "^\[\s*[0-9/]+%?\]\s(Generating)(\s+.*)$",
             performing, "normal,bold"],
         # make errors
         [ "make\[[0-9]+\].*", "yellow"],
         [ "(make: \*\*\* \[.+\] )(.* [0-9]+)", "red", "normal,bold"],
-        # progress percentage
+        # progress percentage (make)
         [ "^(\[\s*[0-9]+%\])","Scale" ]
     ]
